@@ -15,7 +15,7 @@ func init() {
 	})
 }
 
-func streaminfoDecode(d *decode.D, _ any) any {
+func streaminfoDecode(d *decode.D) any {
 	d.FieldU16("minimum_block_size")
 	d.FieldU16("maximum_block_size")
 	d.FieldU24("minimum_frame_size")
