@@ -22,7 +22,6 @@ func init() {
 	})
 }
 
-//nolint:revive
 const (
 	CMD_END    = 0xff
 	FSTA_DSP   = 0x00
@@ -48,7 +47,7 @@ var commandNames = scalar.UintMapSymStr{
 }
 
 func rleValue(d *decode.D) (uint64, uint64, int) {
-	p := uint(d.PeekBits(8))
+	p := uint(d.PeekUintBits(8))
 
 	// match zero prefix
 	switch {
